@@ -36,6 +36,7 @@ from nose.plugins.manager import DefaultPluginManager
 import apiritif
 import apiritif.thread as thread
 import apiritif.store as store
+from apiritif.action_plugins import ActionHandlerFactory, import_plugins
 from apiritif.utils import NormalShutdown, log, get_trace
 
 
@@ -151,6 +152,7 @@ class Worker(ThreadPool):
             store.writer = JTLSampleWriter(self.params.report)
 
     def start(self):
+        import_plugins()
         params = list(self._get_thread_params())
         with store.writer:  # writer must be closed finally
             try:
@@ -189,8 +191,16 @@ class Worker(ThreadPool):
             config.stream = open(os.devnull, "w")  # FIXME: use "with", allow writing to file/log
 
         iteration = 0
+        handlers = ActionHandlerFactory.create_all()
+        log.debug(f'Action handlers created {handlers}')
+        thread.put_into_thread_store(action_handlers=handlers)
+        for handler in handlers:
+            handler.startup()
+
         try:
             while True:
+                if 'GRACEFUL' in os.environ and os.path.exists(os.environ['GRACEFUL']):
+                    break
                 log.debug("Starting iteration:: index=%d,start_time=%.3f", iteration, time.time())
                 thread.set_iteration(iteration)
                 ApiritifTestProgram(config=config)
@@ -215,6 +225,9 @@ class Worker(ThreadPool):
             if params.verbose:
                 config.stream.close()
 
+            for handler in handlers:
+                handler.finalize()
+
     def __reduce__(self):
         raise NotImplementedError()
 
@@ -411,7 +424,6 @@ class ApiritifPlugin(Plugin):
         before test run
         """
         thread.clean_transaction_handlers()
-        thread.clean_logging_handlers()
         addr = test.address()  # file path, package.subpackage.module, class.method
         test_file, module_fqn, class_method = addr
         test_fqn = test.id()  # [package].module.class.method
